summaryrefslogtreecommitdiffstats
path: root/app_templates
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2023-01-16 17:11:02 +0100
committerSlávek Banko <slavek.banko@axis.cz>2023-01-23 02:16:16 +0100
commite55e706f31de58a8286d0b6e53b723d9d199d5c6 (patch)
treed92640d57599b3e8b8332c13830501a701a65d89 /app_templates
parent2d380395d26b5897ffbf92dc62bd0f9ed09e0661 (diff)
downloadpytdeextensions-e55e706f31de58a8286d0b6e53b723d9d199d5c6.tar.gz
pytdeextensions-e55e706f31de58a8286d0b6e53b723d9d199d5c6.zip
Update after renaming qt => tqt in PyTQt module.
Signed-off-by: Slávek Banko <slavek.banko@axis.cz>
Diffstat (limited to 'app_templates')
-rwxr-xr-xapp_templates/kcontrol_module/setup.py2
-rw-r--r--app_templates/kcontrol_module/src/KcontrolModuleWidgetUI.ui4
-rwxr-xr-xapp_templates/kcontrol_module/src/kcontrol_module.py6
-rwxr-xr-xapp_templates/kdeapp/setup.py2
-rwxr-xr-xapp_templates/kdeapp/src/kdeapp.py16
-rw-r--r--app_templates/kdeapp/src/kdeappiface.py2
-rw-r--r--app_templates/kdeapp/src/kdeappview.py16
-rw-r--r--app_templates/kdeapp/src/prefdialog.py18
-rwxr-xr-xapp_templates/kdeutility/setup.py2
-rw-r--r--app_templates/kdeutility/src/KDEUtilityDialogUI.ui4
-rwxr-xr-xapp_templates/kdeutility/src/kdeutility.py2
-rwxr-xr-xapp_templates/tdeioslave/setup.py2
-rwxr-xr-xapp_templates/tdeioslave/src/tdeioslave.py10
13 files changed, 43 insertions, 43 deletions
diff --git a/app_templates/kcontrol_module/setup.py b/app_templates/kcontrol_module/setup.py
index b072cb8..f8b81d3 100755
--- a/app_templates/kcontrol_module/setup.py
+++ b/app_templates/kcontrol_module/setup.py
@@ -23,7 +23,7 @@ tdedistutils.setup(name="kcontrol_module",
author_email="YOUR@EMAIL.com",
url="http://www.TESTAPP.com/",
min_kde_version = "3.0.0",
- min_qt_version = "3.0.0",
+ min_tqt_version = "3.0.0",
license = "GPL",
application_data = ['src/kcontrol_module.py','src/KcontrolModuleWidgetUI.ui'],
executable_links = [('kcontrol_module','kcontrol_module.py')],
diff --git a/app_templates/kcontrol_module/src/KcontrolModuleWidgetUI.ui b/app_templates/kcontrol_module/src/KcontrolModuleWidgetUI.ui
index 4ff94d7..efc23cd 100644
--- a/app_templates/kcontrol_module/src/KcontrolModuleWidgetUI.ui
+++ b/app_templates/kcontrol_module/src/KcontrolModuleWidgetUI.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>KcontrolModuleWidgetUI</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>KcontrolModuleWidgetUI</cstring>
</property>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabel1</cstring>
</property>
diff --git a/app_templates/kcontrol_module/src/kcontrol_module.py b/app_templates/kcontrol_module/src/kcontrol_module.py
index f5cf394..f1c18de 100755
--- a/app_templates/kcontrol_module/src/kcontrol_module.py
+++ b/app_templates/kcontrol_module/src/kcontrol_module.py
@@ -16,7 +16,7 @@
###########################################################################
import sys
-from PyTQt.qt import *
+from PyTQt.tqt import *
from tdecore import *
from tdeui import *
@@ -72,10 +72,10 @@ class KcontrolModuleApp(programbase):
TDEGlobal.iconLoader().addAppDir("kcontrol_module")
if standalone:
- toplayout = QVBoxLayout( self.plainPage(), 0, KDialog.spacingHint() )
+ toplayout = TQVBoxLayout( self.plainPage(), 0, KDialog.spacingHint() )
mainwidget = KcontrolModuleWidget(self.plainPage())
else:
- toplayout = QVBoxLayout( self, 0, KDialog.spacingHint() )
+ toplayout = TQVBoxLayout( self, 0, KDialog.spacingHint() )
mainwidget = KcontrolModuleWidget(self)
toplayout.addWidget(mainwidget)
diff --git a/app_templates/kdeapp/setup.py b/app_templates/kdeapp/setup.py
index 710c6aa..21386c6 100755
--- a/app_templates/kdeapp/setup.py
+++ b/app_templates/kdeapp/setup.py
@@ -23,7 +23,7 @@ tdedistutils.setup(name="kdeapp",
author_email="YOUR@EMAIL.com",
url="http://www.KDEAPP.com/",
min_kde_version = "3.0.0",
- min_qt_version = "3.0.0",
+ min_tqt_version = "3.0.0",
license = "GPL",
application_data = ['src/kdeapp.py','src/prefdialog.py','src/kdeappview.py'],
executable_links = [('kdeapp','kdeapp.py')],
diff --git a/app_templates/kdeapp/src/kdeappiface.py b/app_templates/kdeapp/src/kdeappiface.py
index 1ff3b0f..5600437 100644
--- a/app_templates/kdeapp/src/kdeappiface.py
+++ b/app_templates/kdeapp/src/kdeappiface.py
@@ -20,7 +20,7 @@ from dcopexport import DCOPExObj
class TestAppIface(DCOPExObj):
def __init__(self, parent, id="Value"):
DCOPExObj.__init__(self, id)
- self.addMethod("void openURL(QString url)", self.openURL)
+ self.addMethod("void openURL(TQString url)", self.openURL)
def openURL(self,url):
pass
diff --git a/app_templates/kdeapp/src/kdeappview.py b/app_templates/kdeapp/src/kdeappview.py
index 92ec6df..af2537a 100644
--- a/app_templates/kdeapp/src/kdeappview.py
+++ b/app_templates/kdeapp/src/kdeappview.py
@@ -15,7 +15,7 @@
# #
###########################################################################
-from PyTQt.qt import *
+from PyTQt.tqt import *
from tdecore import *
from tdeui import *
from tdeio import *
@@ -23,13 +23,13 @@ from tdehtml import *
from tdeparts import *
#from kdeappiface import *
-class KdeAppView(QWidget):
+class KdeAppView(TQWidget):
def __init__(self,parent):
- QWidget.__init__(self,parent)
+ TQWidget.__init__(self,parent)
#self._dcopclient= KdeAppIface(self,"KdeAppIface")
# setup our layout manager to automatically add our widgets
- top_layout = QHBoxLayout(self)
+ top_layout = TQHBoxLayout(self)
top_layout.setAutoAdd(True)
if True:
@@ -58,7 +58,7 @@ class KdeAppView(QWidget):
# we now know that our offer can handle HTML and is a part.
# since it is a part, it must also have a library... let's try to
# load that now
- self._html = createReadOnlyPart(ptr.library(),self,ptr.name(),"KParts::ReadOnlyPart",QStringList())
+ self._html = createReadOnlyPart(ptr.library(),self,ptr.name(),"KParts::ReadOnlyPart", TQStringList())
if self._html is not None:
break
@@ -68,8 +68,8 @@ class KdeAppView(QWidget):
KMessageBox.error(self, i18n("Could not find a suitable HTML component"))
return
- QObject.connect(self._html, SIGNAL("setWindowCaption(const QString&)"), self.slotSetTitle)
- QObject.connect(self._html, SIGNAL("setStatusBarText(const QString&)"), self.slotOnURL)
+ TQObject.connect(self._html, SIGNAL("setWindowCaption(const TQString&)"), self.slotSetTitle)
+ TQObject.connect(self._html, SIGNAL("setStatusBarText(const TQString&)"), self.slotOnURL)
def print_(self,p,height,width):
pass
@@ -80,7 +80,7 @@ class KdeAppView(QWidget):
return self._html.url().url()
def openURL(self,url):
- if isinstance(url,QString):
+ if isinstance(url,TQString):
url = KURL(url)
self._html.openURL(url)
diff --git a/app_templates/kdeapp/src/prefdialog.py b/app_templates/kdeapp/src/prefdialog.py
index ef8ec0f..ce58dac 100644
--- a/app_templates/kdeapp/src/prefdialog.py
+++ b/app_templates/kdeapp/src/prefdialog.py
@@ -15,7 +15,7 @@
# #
###########################################################################
-from PyTQt.qt import *
+from PyTQt.tqt import *
from tdecore import *
from tdeui import *
@@ -33,21 +33,21 @@ class TestAppPrefDialog(KDialogBase):
frame = self.addPage(i18n("Second Page"), i18n("Page Two Options"))
self._pageTwo = TestAppPrefPageTwo(frame)
-class TestAppPrefPageOne(QFrame):
+class TestAppPrefPageOne(TQFrame):
def __init__(self,parent):
- QFrame.__init__(self,parent)
+ TQFrame.__init__(self,parent)
- layout = QHBoxLayout(self)
+ layout = TQHBoxLayout(self)
layout.setAutoAdd(True)
- QLabel(i18n("Add something here"), self)
+ TQLabel(i18n("Add something here"), self)
-class TestAppPrefPageTwo(QFrame):
+class TestAppPrefPageTwo(TQFrame):
def __init__(self,parent):
- QFrame.__init__(self,parent)
+ TQFrame.__init__(self,parent)
- layout = QHBoxLayout(self)
+ layout = TQHBoxLayout(self)
layout.setAutoAdd(True)
- QLabel(i18n("Add something here"), self)
+ TQLabel(i18n("Add something here"), self)
diff --git a/app_templates/kdeutility/setup.py b/app_templates/kdeutility/setup.py
index 3a39382..bd75a2b 100755
--- a/app_templates/kdeutility/setup.py
+++ b/app_templates/kdeutility/setup.py
@@ -23,7 +23,7 @@ tdedistutils.setup(name="kdeutility",
author_email="YOUR@EMAIL.com",
url="http://www.TESTAPP.com/",
min_kde_version = "3.0.0",
- min_qt_version = "3.0.0",
+ min_tqt_version = "3.0.0",
license = "GPL",
application_data = ['src/kdeutility.py','src/KDEUtilityDialogUI.ui'],
executable_links = [('kdeutility','kdeutility.py')],
diff --git a/app_templates/kdeutility/src/KDEUtilityDialogUI.ui b/app_templates/kdeutility/src/KDEUtilityDialogUI.ui
index af12ef1..ecf553d 100644
--- a/app_templates/kdeutility/src/KDEUtilityDialogUI.ui
+++ b/app_templates/kdeutility/src/KDEUtilityDialogUI.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>KDEUtilityDialogUI</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>KDEUtilityDialogUI</cstring>
</property>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>hellobutton</cstring>
</property>
diff --git a/app_templates/kdeutility/src/kdeutility.py b/app_templates/kdeutility/src/kdeutility.py
index 6b34826..dc61002 100755
--- a/app_templates/kdeutility/src/kdeutility.py
+++ b/app_templates/kdeutility/src/kdeutility.py
@@ -16,7 +16,7 @@
###########################################################################
import sys
-from PyTQt.qt import *
+from PyTQt.tqt import *
from tdecore import *
from tdeui import *
import tdedesigner
diff --git a/app_templates/tdeioslave/setup.py b/app_templates/tdeioslave/setup.py
index 1e9ff91..ce2a99a 100755
--- a/app_templates/tdeioslave/setup.py
+++ b/app_templates/tdeioslave/setup.py
@@ -23,7 +23,7 @@ tdedistutils.setup(name="tdeioslave",
author_email="YOUR@EMAIL.com",
url="http://www.TESTAPP.com/",
min_kde_version = "3.0.0",
- min_qt_version = "3.0.0",
+ min_tqt_version = "3.0.0",
license = "GPL",
application_data = ['src/tdeioslave.py'],
docbooks = [ ('doc/en','en') ],
diff --git a/app_templates/tdeioslave/src/tdeioslave.py b/app_templates/tdeioslave/src/tdeioslave.py
index 17f9ee8..7685254 100755
--- a/app_templates/tdeioslave/src/tdeioslave.py
+++ b/app_templates/tdeioslave/src/tdeioslave.py
@@ -15,8 +15,8 @@
# #
###########################################################################
-# Import the required Qt and KDE modules.
-from PyTQt.qt import *
+# Import the required TQt and KDE modules.
+from PyTQt.tqt import *
from tdeio import *
from tdecore import *
import os, time
@@ -102,10 +102,10 @@ class SlaveClass(TDEIO.SlaveBase):
self.error(TDEIO.ERR_IS_DIRECTORY, path)
self.totalSize(len(item.getData()))
- self.data(QByteArray(item.getData()))
+ self.data(TQByteArray(item.getData()))
# The end of the data string.
- self.data(QByteArray())
+ self.data(TQByteArray())
self.finished()
@@ -132,7 +132,7 @@ class SlaveClass(TDEIO.SlaveBase):
parent_dir.unlink(filename)
# Read data from the application.
- bytearray = QByteArray()
+ bytearray = TQByteArray()
bytes = 0
data = ""
diff --git a/app_templates/kdeapp/src/kdeapp.py b/app_templates/kdeapp/src/kdeapp.py
index 842d283..68d07af 100755
--- a/app_templates/kdeapp/src/kdeapp.py
+++ b/app_templates/kdeapp/src/kdeapp.py
@@ -15,7 +15,7 @@
# #
###########################################################################
-from PyTQt.qt import *
+from PyTQt.tqt import *
from tdecore import *
from tdeui import *
import sys
@@ -55,7 +55,7 @@ class KdeApp(TDEMainWindow):
self.connect(self._view, PYSIGNAL("signalChangeCaption"), self.changeCaption)
def load(self,url):
- target = QString()
+ target = TQString()
# the below code is what you should normally do. in this
# example case, we want the url to our own. you probably
# want to use this code instead for your app
@@ -124,7 +124,7 @@ class KdeApp(TDEMainWindow):
def dropEvent(self,event):
# this is a very simplistic implementation of a drop event. we
- # will only accept a dropped URL. the Qt dnd code can do *much*
+ # will only accept a dropped URL. the TQt dnd code can do *much*
# much more, so please read the docs there
urls = KURL.List()
@@ -150,7 +150,7 @@ class KdeApp(TDEMainWindow):
# button is clicked
## this brings up the generic open dialog
- #KURL url = KURLRequesterDlg::getURL(QString::null, this, i18n("Open Location") );
+ #KURL url = KURLRequesterDlg::getURL(TQString::null, this, i18n("Open Location") );
# standard filedialog
url = KFileDialog.getOpenURL(None, One, self, i18n("Open Location"))
@@ -181,14 +181,14 @@ class KdeApp(TDEMainWindow):
self._printer = KPrinter()
if self._printer.setup(self):
# setup the printer. with Qt, you always "print" to a
# QPainter.. whether the output medium is a pixmap, a screen,
# or paper
- p = QPainter()
+ p = TQPainter()
p.begin(self._printer)
# we let our view do the actual printing
- metrics = QPaintDeviceMetrics(m_printer)
+ metrics = TQPaintDeviceMetrics(m_printer)
self._view.print_(p, metrics.height(), metrics.width())
# and send the result to the printer
@@ -181,14 +181,14 @@ class KdeApp(TDEMainWindow):
self._printer = KPrinter()
if self._printer.setup(self):
- # setup the printer. with Qt, you always "print" to a
- # QPainter.. whether the output medium is a pixmap, a screen,
+ # setup the printer. with TQt, you always "print" to a
+ # TQPainter.. whether the output medium is a pixmap, a screen,
# or paper